Attribute Macros
- extend_
arbitrary - Extend the
Arbitrarytrait for target struct based on its constructor(e.g.,newmethod). Add this attribute to the impl block of the struct. - kani_
arbitrary - Impl
Arbitraryfor a struct by generating theanymethod based on the fields of the struct. - kani_
test - Automatedly generate Kani one test harness for target function.
The harness name is
check_{function_name}.